@@ -76,10 +76,10 @@ class Field(FieldABC):
     data does not need to be formatted before being serialized or deserialized.
     On error, the name of the field will be returned.
 
-    :param default: If set, this value will be used during serialization if the input value
-        is missing. If not set, the field will be excluded from the serialized output if the
-        input value is missing. May be a value or a callable.
-    :param missing: Default deserialization value for the field if the field is not
+    :param dump_default: If set, this value will be used during serialization if the
+        input value is missing. If not set, the field will be excluded from the
+        serialized output if the input value is missing. May be a value or a callable.
+    :param load_default: Default deserialization value for the field if the field is not
         found in the input data. May be a value or a callable.
     :param data_key: The name of the dict key in the external representation, i.e.
         the input of `load` and the output of `dump`.
@@ -148,8 +148,10 @@ class Field(FieldABC):
     def __init__(
         self,
         *,
-        default: typing.Any = missing_,
+        load_default: typing.Any = missing_,
         missing: typing.Any = missing_,
+        dump_default: typing.Any = missing_,
+        default: typing.Any = missing_,
         data_key: typing.Optional[str] = None,
         attribute: typing.Optional[str] = None,
         validate: typing.Optional[
@@ -164,9 +166,28 @@ class Field(FieldABC):
         dump_only: bool = False,
         error_messages: typing.Optional[typing.Dict[str, str]] = None,
         metadata: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        **additional_metadata
+        **additional_metadata,
     ) -> None:
-        self.default = default
+        # handle deprecated `default` and `missing` parameters
+        if default is not missing_:
+            warnings.warn(
+                "The 'default' argument to fields is deprecated. "
+                "Use 'dump_default' instead.",
+                RemovedInMarshmallow4Warning,
+            )
+            if dump_default is missing_:
+                dump_default = default
+        if missing is not missing_:
+            warnings.warn(
+                "The 'missing' argument to fields is deprecated. "
+                "Use 'load_default' instead.",
+                RemovedInMarshmallow4Warning,
+            )
+            if load_default is missing_:
+                load_default = missing
+        self.dump_default = dump_default
+        self.load_default = load_default
+
         self.attribute = attribute
         self.data_key = data_key
         self.validate = validate
@@ -182,22 +203,22 @@ class Field(FieldABC):
                 "or a collection of callables."
             )
 
-        # If allow_none is None and missing is None
+        # If allow_none is None and load_default is None
         # None should be considered valid by default
-        self.allow_none = missing is None if allow_none is None else allow_none
+        self.allow_none = load_default is None if allow_none is None else allow_none
         self.load_only = load_only
         self.dump_only = dump_only
-        if required is True and missing is not missing_:
-            raise ValueError("'missing' must not be set for required fields.")
+        if required is True and load_default is not missing_:
+            raise ValueError("'load_default' must not be set for required fields.")
         self.required = required
-        self.missing = missing
 
         metadata = metadata or {}
         self.metadata = {**metadata, **additional_metadata}
         if additional_metadata:
             warnings.warn(
-                "Passing field metadata as a keyword arg is deprecated. Use the "
-                "explicit `metadata=...` argument instead.",
+                "Passing field metadata as keyword arguments is deprecated. Use the "
+                "explicit `metadata=...` argument instead. "
+                f"Additional metadata: {additional_metadata}",
                 RemovedInMarshmallow4Warning,
             )
 
@@ -213,11 +234,11 @@ class Field(FieldABC):
 
     def __repr__(self) -> str:
         return (
-            "<fields.{ClassName}(default={self.default!r}, "
+            "<fields.{ClassName}(dump_default={self.dump_default!r}, "
             "attribute={self.attribute!r}, "
             "validate={self.validate}, required={self.required}, "
             "load_only={self.load_only}, dump_only={self.dump_only}, "
-            "missing={self.missing}, allow_none={self.allow_none}, "
+            "load_default={self.load_default}, allow_none={self.allow_none}, "
             "error_messages={self.error_messages})>".format(
                 ClassName=self.__class__.__name__, self=self
             )
@@ -296,7 +317,7 @@ class Field(FieldABC):
         accessor: typing.Optional[
             typing.Callable[[typing.Any, str, typing.Any], typing.Any]
         ] = None,
-        **kwargs
+        **kwargs,
     ):
         """Pulls the value for the given key from the object, applies the
         field's formatting and returns the result.
@@ -309,7 +330,7 @@ class Field(FieldABC):
         if self._CHECK_ATTRIBUTE:
             value = self.get_value(obj, attr, accessor=accessor)
             if value is missing_:
-                default = self.default
+                default = self.dump_default
                 value = default() if callable(default) else default
             if value is missing_:
                 return value
@@ -322,7 +343,7 @@ class Field(FieldABC):
         value: typing.Any,
         attr: typing.Optional[str] = None,
         data: typing.Optional[typing.Mapping[str, typing.Any]] = None,
-        **kwargs
+        **kwargs,
     ):
         """Deserialize ``value``.
 
@@ -337,7 +358,7 @@ class Field(FieldABC):
         # deserialized value
         self._validate_missing(value)
         if value is missing_:
-            _miss = self.missing
+            _miss = self.load_default
             return _miss() if callable(_miss) else _miss
         if self.allow_none and value is None:
             return None
@@ -385,7 +406,7 @@ class Field(FieldABC):
         value: typing.Any,
         attr: typing.Optional[str],
         data: typing.Optional[typing.Mapping[str, typing.Any]],
-        **kwargs
+        **kwargs,
     ):
         """Deserialize value. Concrete :class:`Field` classes should implement this method.
 
@@ -411,6 +432,44 @@ class Field(FieldABC):
         """The context dictionary for the parent :class:`Schema`."""
         return self.parent.context
 
+    # the default and missing properties are provided for compatibility and
+    # emit warnings when they are accessed and set
+    @property
+    def default(self):
+        warnings.warn(
+            "The 'default' attribute of fields is deprecated. "
+            "Use 'dump_default' instead.",
+            RemovedInMarshmallow4Warning,
+        )
+        return self.dump_default
+
+    @default.setter
+    def default(self, value):
+        warnings.warn(
+            "The 'default' attribute of fields is deprecated. "
+            "Use 'dump_default' instead.",
+            RemovedInMarshmallow4Warning,
+        )
+        self.dump_default = value
+
+    @property
+    def missing(self):
+        warnings.warn(
+            "The 'missing' attribute of fields is deprecated. "
+            "Use 'load_default' instead.",
+            RemovedInMarshmallow4Warning,
+        )
+        return self.load_default
+
+    @missing.setter
+    def missing(self, value):
+        warnings.warn(
+            "The 'missing' attribute of fields is deprecated. "
+            "Use 'load_default' instead.",
+            RemovedInMarshmallow4Warning,
+        )
+        self.load_default = value
+
 
 class Raw(Field):
     """Field that applies no formatting."""
@@ -467,12 +526,13 @@ class Nested(Field):
         self,
         nested: typing.Union[SchemaABC, type, str, typing.Callable[[], SchemaABC]],
         *,
+        dump_default: typing.Any = missing_,
         default: typing.Any = missing_,
         only: typing.Optional[types.StrSequenceOrSet] = None,
         exclude: types.StrSequenceOrSet = (),
         many: bool = False,
         unknown: typing.Optional[str] = None,
-        **kwargs
+        **kwargs,
     ):
         # Raise error if only or exclude is passed as string, not list of strings
         if only is not None and not is_collection(only):
@@ -493,7 +553,7 @@ class Nested(Field):
         self.many = many
         self.unknown = unknown
         self._schema = None  # Cached Schema instance
-        super().__init__(default=default, **kwargs)
+        super().__init__(default=default, dump_default=dump_default, **kwargs)
 
     @property
     def schema(self):
@@ -620,7 +680,7 @@ class Pluck(Nested):
         self,
         nested: typing.Union[SchemaABC, type, str, typing.Callable[[], SchemaABC]],
         field_name: str,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(nested, only=(field_name,), **kwargs)
         self.field_name = field_name
@@ -1009,7 +1069,7 @@ class Decimal(Number):
         *,
         allow_nan: bool = False,
         as_string: bool = False,
-        **kwargs
+        **kwargs,
     ):
         self.places = (
             decimal.Decimal((0, (1,), -places)) if places is not None else None
@@ -1102,7 +1162,7 @@ class Boolean(Field):
         *,
         truthy: typing.Optional[typing.Set] = None,
         falsy: typing.Optional[typing.Set] = None,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(**kwargs)
 
@@ -1249,7 +1309,7 @@ class NaiveDateTime(DateTime):
         format: typing.Optional[str] = None,
         *,
         timezone: typing.Optional[dt.timezone] = None,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(format=format, **kwargs)
         self.timezone = timezone
@@ -1286,7 +1346,7 @@ class AwareDateTime(DateTime):
         format: typing.Optional[str] = None,
         *,
         default_timezone: typing.Optional[dt.tzinfo] = None,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(format=format, **kwargs)
         self.default_timezone = default_timezone
@@ -1401,7 +1461,7 @@ class TimeDelta(Field):
 
         if precision not in units:
             msg = 'The precision must be {} or "{}".'.format(
-                ", ".join(['"{}"'.format(each) for each in units[:-1]]), units[-1]
+                ", ".join([f'"{each}"' for each in units[:-1]]), units[-1]
             )
             raise ValueError(msg)
 
@@ -1412,7 +1472,9 @@ class TimeDelta(Field):
         if value is None:
             return None
         base_unit = dt.timedelta(**{self.precision: 1})
-        return int(value.total_seconds() / base_unit.total_seconds())
+        delta = utils.timedelta_to_microseconds(value)
+        unit = utils.timedelta_to_microseconds(base_unit)
+        return delta // unit
 
     def _deserialize(self, value, attr, data, **kwargs):
         try:
@@ -1451,7 +1513,7 @@ class Mapping(Field):
         self,
         keys: typing.Optional[typing.Union[Field, type]] = None,
         values: typing.Optional[typing.Union[Field, type]] = None,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(**kwargs)
         if keys is None:
@@ -1597,7 +1659,7 @@ class Url(String):
         relative: bool = False,
         schemes: typing.Optional[types.StrSequenceOrSet] = None,
         require_tld: bool = True,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(**kwargs)
 
@@ -1699,7 +1761,7 @@ class IPInterface(Field):
 
     see https://python.readthedocs.io/en/latest/library/ipaddress.html#interface-objects
 
-    :parm bool exploded: If `True`, serialize ipv6 interface in long form, ie. with groups
+    :param bool exploded: If `True`, serialize ipv6 interface in long form, ie. with groups
         consisting entirely of zeros included.
     """
 
@@ -1776,7 +1838,7 @@ class Method(Field):
         self,
         serialize: typing.Optional[str] = None,
         deserialize: typing.Optional[str] = None,
-        **kwargs
+        **kwargs,
     ):
         # Set dump_only and load_only based on arguments
         kwargs["dump_only"] = bool(serialize) and not bool(deserialize)
@@ -1850,7 +1912,7 @@ class Function(Field):
                 typing.Callable[[typing.Any, typing.Dict], typing.Any],
             ]
         ] = None,
-        **kwargs
+        **kwargs,
     ):
         # Set dump_only and load_only based on arguments
         kwargs["dump_only"] = bool(serialize) and not bool(deserialize)
@@ -1870,7 +1932,7 @@ class Function(Field):
     def _call_or_raise(self, func, value, attr):
         if len(utils.get_func_args(func)) > 1:
             if self.parent.context is None:
-                msg = "No context available for Function field {!r}".format(attr)
+                msg = f"No context available for Function field {attr!r}"
                 raise ValidationError(msg)
             return func(value, self.parent.context)
         else:
@@ -1892,8 +1954,8 @@ class Constant(Field):
     def __init__(self, constant: typing.Any, **kwargs):
         super().__init__(**kwargs)
         self.constant = constant
-        self.missing = constant
-        self.default = constant
+        self.load_default = constant
+        self.dump_default = constant
 
     def _serialize(self, value, *args, **kwargs):
         return self.constant
