@@ -42,6 +42,7 @@ def _get_fields(attrs, ordered=False):
     """Get fields from a class. If ordered=True, fields will sorted by creation index.
 
     :param attrs: Mapping of class attributes
+    :param bool ordered: Sort fields by creation index
     """
     fields = [
         (field_name, field_value)
@@ -98,6 +99,10 @@ class SchemaMeta(type):
             else:
                 ordered = False
         cls_fields = _get_fields(attrs, ordered=ordered)
+        # Remove fields from list of class attributes to avoid shadowing
+        # Schema attributes/methods in case of name conflict
+        for field_name, _ in cls_fields:
+            del attrs[field_name]
         klass = super().__new__(mcs, name, bases, attrs)
         inherited_fields = _get_fields_by_mro(klass, ordered=ordered)
 
@@ -366,7 +371,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         load_only: types.StrSequenceOrSet = (),
         dump_only: types.StrSequenceOrSet = (),
         partial: typing.Union[bool, types.StrSequenceOrSet] = False,
-        unknown: typing.Optional[str] = None
+        unknown: typing.Optional[str] = None,
     ):
         # Raise error if only or exclude is passed as string, not list of strings
         if only is not None and not is_collection(only):
@@ -415,7 +420,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         cls,
         fields: typing.Dict[str, typing.Union[ma_fields.Field, type]],
         *,
-        name: str = "GeneratedSchema"
+        name: str = "GeneratedSchema",
     ) -> type:
         """Generate a `Schema` class given a dictionary of fields.
 
@@ -583,7 +588,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         many: bool = False,
         partial=False,
         unknown=RAISE,
-        index=None
+        index=None,
     ) -> typing.Union[_T, typing.List[_T]]:
         """Deserialize ``data``.
 
@@ -689,7 +694,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         *,
         many: typing.Optional[bool] = None,
         partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
-        unknown: typing.Optional[str] = None
+        unknown: typing.Optional[str] = None,
     ):
         """Deserialize a data structure to an object defined by this Schema's fields.
 
@@ -722,7 +727,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         many: typing.Optional[bool] = None,
         partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
         unknown: typing.Optional[str] = None,
-        **kwargs
+        **kwargs,
     ):
         """Same as :meth:`load`, except it takes a JSON string as input.
 
@@ -757,7 +762,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         many,
         partial,
         pass_original,
-        index=None
+        index=None,
     ):
         try:
             if pass_original:  # Pass original, raw data (before unmarshalling)
@@ -769,10 +774,13 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
 
     def validate(
         self,
-        data: typing.Mapping,
+        data: typing.Union[
+            typing.Mapping[str, typing.Any],
+            typing.Iterable[typing.Mapping[str, typing.Any]],
+        ],
         *,
         many: typing.Optional[bool] = None,
-        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None
+        partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
     ) -> typing.Dict[str, typing.List[str]]:
         """Validate `data` against the schema, returning a dictionary of
         validation errors.
@@ -806,7 +814,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         many: typing.Optional[bool] = None,
         partial: typing.Optional[typing.Union[bool, types.StrSequenceOrSet]] = None,
         unknown: typing.Optional[str] = None,
-        postprocess: bool = True
+        postprocess: bool = True,
     ):
         """Deserialize `data`, returning the deserialized result.
         This method is private API.
@@ -962,7 +970,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             invalid_fields |= self.exclude - available_field_names
 
         if invalid_fields:
-            message = "Invalid fields for {}: {}.".format(self, invalid_fields)
+            message = f"Invalid fields for {self}: {invalid_fields}."
             raise ValueError(message)
 
         fields_dict = self.dict_class()
@@ -1067,7 +1075,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         *,
         many: bool,
         original_data,
-        partial: typing.Union[bool, types.StrSequenceOrSet]
+        partial: typing.Union[bool, types.StrSequenceOrSet],
     ):
         # This has to invert the order of the dump processors, so run the pass_many
         # processors first.
@@ -1100,9 +1108,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
             except KeyError as error:
                 if field_name in self.declared_fields:
                     continue
-                raise ValueError(
-                    '"{}" field does not exist.'.format(field_name)
-                ) from error
+                raise ValueError(f'"{field_name}" field does not exist.') from error
 
             data_key = (
                 field_obj.data_key if field_obj.data_key is not None else field_name
@@ -1147,7 +1153,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         original_data,
         many: bool,
         partial: typing.Union[bool, types.StrSequenceOrSet],
-        field_errors: bool = False
+        field_errors: bool = False,
     ):
         for attr_name in self._hooks[(VALIDATES_SCHEMA, pass_many)]:
             validator = getattr(self, attr_name)
@@ -1189,7 +1195,7 @@ class Schema(base.SchemaABC, metaclass=SchemaMeta):
         data,
         many: bool,
         original_data=None,
-        **kwargs
+        **kwargs,
     ):
         key = (tag, pass_many)
         for attr_name in self._hooks[key]:
