@@ -1,18 +1,21 @@
 """Validation classes for various types of data."""
 import re
+import typing
+from abc import ABC, abstractmethod
 from itertools import zip_longest
 from operator import attrgetter
-import typing
 
 from marshmallow import types
 from marshmallow.exceptions import ValidationError
 
+_T = typing.TypeVar("_T")
 
-class Validator:
-    """Base abstract class for validators.
+
+class Validator(ABC):
+    """Abstract base class for validators.
 
     .. note::
-        This class does not provide any behavior. It is only used to
+        This class does not provide any validation behavior. It is only used to
         add a useful `__repr__` implementation for validators.
     """
 
@@ -20,7 +23,7 @@ class Validator:
 
     def __repr__(self) -> str:
         args = self._repr_args()
-        args = "{}, ".format(args) if args else ""
+        args = f"{args}, " if args else ""
 
         return "<{self.__class__.__name__}({args}error={self.error!r})>".format(
             self=self, args=args
@@ -32,6 +35,60 @@ class Validator:
         """
         return ""
 
+    @abstractmethod
+    def __call__(self, value: typing.Any) -> typing.Any:
+        ...
+
+
+class And(Validator):
+    """Compose multiple validators and combine their error messages.
+
+    Example: ::
+
+        from marshmallow import validate, ValidationError
+
+        def is_even(value):
+            if value % 2 != 0:
+                raise ValidationError("Not an even value.")
+
+        validator = validate.And(validate.Range(min=0), is_even)
+        validator(-1)
+        # ValidationError: ['Must be greater than or equal to 0.', 'Not an even value.']
+
+    :param validators: Validators to combine.
+    :param error: Error message to use when a validator returns ``False``.
+    """
+
+    default_error_message = "Invalid value."
+
+    def __init__(
+        self, *validators: types.Validator, error: typing.Optional[str] = None
+    ):
+        self.validators = tuple(validators)
+        self.error = error or self.default_error_message  # type: str
+
+    def _repr_args(self) -> str:
+        return f"validators={self.validators!r}"
+
+    def __call__(self, value: typing.Any) -> typing.Any:
+        errors = []
+        kwargs = {}
+        for validator in self.validators:
+            try:
+                r = validator(value)
+                if not isinstance(validator, Validator) and r is False:
+                    raise ValidationError(self.error)
+            except ValidationError as err:
+                kwargs.update(err.kwargs)
+                if isinstance(err.messages, dict):
+                    errors.append(err.messages)
+                else:
+                    # FIXME : Get rid of cast
+                    errors.extend(typing.cast(list, err.messages))
+        if errors:
+            raise ValidationError(errors, **kwargs)
+        return value
+
 
 class URL(Validator):
     """Validate a URL.
@@ -48,7 +105,7 @@ class URL(Validator):
         def __init__(self):
             self._memoized = {}
 
-        def _regex_generator(self, relative: bool, require_tld: bool):
+        def _regex_generator(self, relative: bool, require_tld: bool) -> typing.Pattern:
             return re.compile(
                 r"".join(
                     (
@@ -94,7 +151,7 @@ class URL(Validator):
         relative: bool = False,
         schemes: typing.Optional[types.StrSequenceOrSet] = None,
         require_tld: bool = True,
-        error: typing.Optional[str] = None
+        error: typing.Optional[str] = None,
     ):
         self.relative = relative
         self.error = error or self.default_message  # type: str
@@ -102,12 +159,12 @@ class URL(Validator):
         self.require_tld = require_tld
 
     def _repr_args(self) -> str:
-        return "relative={!r}".format(self.relative)
+        return f"relative={self.relative!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: str) -> str:
         message = self._format_error(value)
         if not value:
             raise ValidationError(message)
@@ -157,10 +214,10 @@ class Email(Validator):
     def __init__(self, *, error: typing.Optional[str] = None):
         self.error = error or self.default_message  # type: str
 
-    def _format_error(self, value) -> typing.Any:
+    def _format_error(self, value: str) -> str:
         return self.error.format(input=value)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: str) -> str:
         message = self._format_error(value)
 
         if not value or "@" not in value:
@@ -220,7 +277,7 @@ class Range(Validator):
         *,
         min_inclusive: bool = True,
         max_inclusive: bool = True,
-        error: typing.Optional[str] = None
+        error: typing.Optional[str] = None,
     ):
         self.min = min
         self.max = max
@@ -245,10 +302,10 @@ class Range(Validator):
             self.min, self.max, self.min_inclusive, self.max_inclusive
         )
 
-    def _format_error(self, value, message: str) -> str:
+    def _format_error(self, value: _T, message: str) -> str:
         return (self.error or message).format(input=value, min=self.min, max=self.max)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: _T) -> _T:
         if self.min is not None and (
             value < self.min if self.min_inclusive else value <= self.min
         ):
@@ -290,7 +347,7 @@ class Length(Validator):
         max: typing.Optional[int] = None,
         *,
         equal: typing.Optional[int] = None,
-        error: typing.Optional[str] = None
+        error: typing.Optional[str] = None,
     ):
         if equal is not None and any([min, max]):
             raise ValueError(
@@ -304,14 +361,14 @@ class Length(Validator):
         self.equal = equal
 
     def _repr_args(self) -> str:
-        return "min={!r}, max={!r}, equal={!r}".format(self.min, self.max, self.equal)
+        return f"min={self.min!r}, max={self.max!r}, equal={self.equal!r}"
 
-    def _format_error(self, value, message: str) -> str:
+    def _format_error(self, value: typing.Sized, message: str) -> str:
         return (self.error or message).format(
             input=value, min=self.min, max=self.max, equal=self.equal
         )
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: typing.Sized) -> typing.Sized:
         length = len(value)
 
         if self.equal is not None:
@@ -346,12 +403,12 @@ class Equal(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "comparable={!r}".format(self.comparable)
+        return f"comparable={self.comparable!r}"
 
-    def _format_error(self, value) -> str:
+    def _format_error(self, value: _T) -> str:
         return self.error.format(input=value, other=self.comparable)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: _T) -> _T:
         if value != self.comparable:
             raise ValidationError(self._format_error(value))
         return value
@@ -377,9 +434,9 @@ class Regexp(Validator):
     def __init__(
         self,
         regex: typing.Union[str, bytes, typing.Pattern],
-        flags=0,
+        flags: int = 0,
         *,
-        error: typing.Optional[str] = None
+        error: typing.Optional[str] = None,
     ):
         self.regex = (
             re.compile(regex, flags) if isinstance(regex, (str, bytes)) else regex
@@ -387,12 +444,20 @@ class Regexp(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "regex={!r}".format(self.regex)
+        return f"regex={self.regex!r}"
 
-    def _format_error(self, value) -> str:
+    def _format_error(self, value: typing.Union[str, bytes]) -> str:
         return self.error.format(input=value, regex=self.regex.pattern)
 
-    def __call__(self, value) -> typing.Any:
+    @typing.overload
+    def __call__(self, value: str) -> str:
+        ...
+
+    @typing.overload
+    def __call__(self, value: bytes) -> bytes:
+        ...
+
+    def __call__(self, value):
         if self.regex.match(value) is None:
             raise ValidationError(self._format_error(value))
 
@@ -419,12 +484,12 @@ class Predicate(Validator):
         self.kwargs = kwargs
 
     def _repr_args(self) -> str:
-        return "method={!r}, kwargs={!r}".format(self.method, self.kwargs)
+        return f"method={self.method!r}, kwargs={self.kwargs!r}"
 
-    def _format_error(self, value) -> str:
+    def _format_error(self, value: typing.Any) -> str:
         return self.error.format(input=value, method=self.method)
 
-    def __call__(self, value) -> str:
+    def __call__(self, value: typing.Any) -> typing.Any:
         method = getattr(value, self.method)
 
         if not method(**self.kwargs):
@@ -451,12 +516,12 @@ class NoneOf(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "iterable={!r}".format(self.iterable)
+        return f"iterable={self.iterable!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(input=value, values=self.values_text)
 
-    def __call__(self, value) -> str:
+    def __call__(self, value: typing.Any) -> typing.Any:
         try:
             if value in self.iterable:
                 raise ValidationError(self._format_error(value))
@@ -482,7 +547,7 @@ class OneOf(Validator):
         choices: typing.Iterable,
         labels: typing.Optional[typing.Iterable[str]] = None,
         *,
-        error: typing.Optional[str] = None
+        error: typing.Optional[str] = None,
     ):
         self.choices = choices
         self.choices_text = ", ".join(str(choice) for choice in self.choices)
@@ -491,14 +556,14 @@ class OneOf(Validator):
         self.error = error or self.default_message  # type: str
 
     def _repr_args(self) -> str:
-        return "choices={!r}, labels={!r}".format(self.choices, self.labels)
+        return f"choices={self.choices!r}, labels={self.labels!r}"
 
     def _format_error(self, value) -> str:
         return self.error.format(
             input=value, choices=self.choices_text, labels=self.labels_text
         )
 
-    def __call__(self, value) -> str:
+    def __call__(self, value: typing.Any) -> typing.Any:
         try:
             if value not in self.choices:
                 raise ValidationError(self._format_error(value))
@@ -549,7 +614,7 @@ class ContainsOnly(OneOf):
         value_text = ", ".join(str(val) for val in value)
         return super()._format_error(value_text)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: typing.Sequence[_T]) -> typing.Sequence[_T]:
         # We can't use set.issubset because does not handle unhashable types
         for val in value:
             if val not in self.choices:
@@ -574,7 +639,7 @@ class ContainsNoneOf(NoneOf):
         value_text = ", ".join(str(val) for val in value)
         return super()._format_error(value_text)
 
-    def __call__(self, value) -> typing.Any:
+    def __call__(self, value: typing.Sequence[_T]) -> typing.Sequence[_T]:
         for val in value:
             if val in self.iterable:
                 raise ValidationError(self._format_error(value))
